@@ -51,23 +51,9 @@ class StorageClient(Client):
             for blob in new_blobs:
                 blob.delete()
 
-    def storage_to_bigquery(self, objects: list, table_ref, write_disposition, batch_size=5000, objects_name=None):
-        """
-        Function that stores data into multiple storage blobs. Afterwards these wil be composed into one storage blob.
-        The reason for this process is to downsize the sie of the data send to Google Cloud Storage.
-
-        Args:
-            objects: dataclasses to process
-            table_ref: dataset_name.table_name
-            write_disposition: how to write to google bigquery
-            batch_size: row size blobs will be created in google storage before they are composed and send to bigquery
-            objects_name: name of the them objects stored in storage 
-        """
-
+    def __list_to_storage(self, objects, objects_name, batch_size):
         assert len(objects) > 0, 'List is empty. No data is send'
 
-        if objects_name is None:
-            objects_name = objects[0].__class__.__name__  # retrieve name of the first object
         random_string = ''.join(random.choice(string.ascii_lowercase) for _ in
                                 range(12))  # Make blob_base_name unique so processes don't interact
         blob_base_name = f'{objects_name}_{random_string}'  # Generate a dynamic name from the object
@@ -78,35 +64,82 @@ class StorageClient(Client):
             batch = objects[i:i + batch_size]
             nl_json_batch = nlj.dumps(list(map(lambda x: rec_to_json(x), batch)))
             # Blobs will be stored in folder import
-            blob = self.bucket.blob(f'import/{i}_{blob_base_name}.json')
+            blob = self.bucket.blob(f'import/{blob_base_name}.json')
             blobs.append(blob)
             blob.upload_from_string(nl_json_batch)
 
-        self.__rec_compose(blobs=blobs, blob_name=blob_base_name, table_ref=table_ref,
+        return blobs
+
+    def storage_to_bigquery(self, objects: list, table_ref, write_disposition, batch_size=5000,
+                            objects_name=None):
+        """
+        Function that stores data into multiple storage blobs. Afterwards these wil be composed into one storage blob.
+        The reason for this process is to downsize the sie of the data send to Google Cloud Storage.
+
+        Args:
+            objects: dataclasses to process
+            table_ref: dataset_name.table_name
+            write_disposition: how to write to google bigquery
+            batch_size: row size blobs will be created in google storage before they are composed and send to bigquery
+            objects_name: name of the them objects stored in storage
+        """
+
+        if objects_name is None:
+            objects_name = objects[0].__class__.__name__  # retrieve name of the first object
+
+        blobs = self.__list_to_storage(objects, objects_name, batch_size)
+
+        self.__rec_compose(blobs=blobs, blob_name=f'{objects_name}_{generate_random_string()}', table_ref=table_ref,
                            write_disposition=write_disposition)
 
+    def batch_storage_to_bigquery(self, objects: list, table_ref, write_disposition, finished: bool = True,
+                                  batch_size=5000,
+                                  objects_name=None):
+        """
+        Function that stores data into multiple storage blobs. If finished these wil be composed into one storage blob.
+        The reason for this process is to downsize the sie of the data send to Google Cloud Storage.
+
+        Args:
+            objects: dataclasses to process
+            table_ref: dataset_name.table_name
+            write_disposition: how to write to google bigquery
+            finished: triggers composing all the blobs and storing them in one procedure
+            batch_size: row size blobs will be created in google storage before they are composed and send to bigquery
+            objects_name: name of the them objects stored in storage
+        """
+
+        if objects_name is None:
+            objects_name = objects[0].__class__.__name__  # retrieve name of the first object
+
+        self.__list_to_storage(objects, objects_name, batch_size)
+
+        if finished:
+            blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'import/{objects_name}')
+            self.__rec_compose(blobs=blobs, blob_name=f'{objects_name}_{generate_random_string()}',
+                               table_ref=table_ref, write_disposition=write_disposition)
+
     def single_storage_to_bigquery(self, object, table_ref, write_disposition, batch_size=500, object_name=None):
         """
-        Function that stores data into a storage blob. Then check if there are more than the batch_size. 
+        Function that stores data into a storage blob. Then check if there are more than the batch_size.
         If so it will compose similar blobs and send them to google bigquery.
         The reason for this process is to not stream single rows of data into bigquery but wait until there are more and than send them together.
-        
-        Args:            
+
+        Args:
             object: dataclass
             table_ref: dataset_name.table_name
             write_disposition: how to write to google bigquery
             batch_size: how many blobs until composing and sending to google bigquery
-            object_name: name of the them object stored in storage 
+            object_name: name of the them object stored in storage
         """
         if object_name is None:
             object_name = object.__class__.__name__  # retrieve name of the object
         blob_base_name = f'{object_name}_{generate_random_string()}'  # Generate a dynamic name from the object
 
         nl_json = nlj.dumps([rec_to_json(object)])
-        blob = self.bucket.blob(f'import/{object_name}/{blob_base_name}.json')
+        blob = self.bucket.blob(f'single_import/{object_name}/{blob_base_name}.json')
         blob.upload_from_string(nl_json)
 
-        blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'import/{object_name}/')
+        blobs = self.list_blobs_with_prefix(bucket_name=self.bucket_name, prefix=f'single_import/{object_name}')
 
         if len(blobs) > batch_size:
             self.__rec_compose(blobs=blobs, blob_name=f'{object_name}_{generate_random_string()}',
